==> kadaster-gds2-1.3-sources.jar: nl/kadaster/schemas/gds2/afgifte_bestandophalenresultaat/afgifte/v20130701/ObjectFactory.java <==

package nl.kadaster.schemas.gds2.afgifte_bestandophalenresultaat.afgifte.v20130701;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlElementDecl;
import javax.xml.bind.annotation.XmlRegistry;
import javax.xml.namespace.QName;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the nl.kadaster.schemas.gds2.afgifte_bestandophalenresultaat.afgifte.v20130701 package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {

    private final static QName _AfgifteBestand_QNAME = new QName("http://www.kadaster.nl/schemas/gds2/afgifte-bestandophalenresultaat/afgifte/v20130701", "AfgifteBestand");
    private final static QName _Afgifte_QNAME = new QName("http://www.kadaster.nl/schemas/gds2/afgifte-bestandophalenresultaat/afgifte/v20130701", "Afgifte");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: nl.kadaster.schemas.gds2.afgifte_bestandophalenresultaat.afgifte.v20130701
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link AfgifteType }
     * 
     */
    public AfgifteType createAfgifteType() {
        return new AfgifteType();
    }

    /**
     * Create an instance of {@link AfgifteBestandType }
     * 
     */
    public AfgifteBestandType createAfgifteBestandType() {
        return new AfgifteBestandType();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link AfgifteBestandType }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://www.kadaster.nl/schemas/gds2/afgifte-bestandophalenresultaat/afgifte/v20130701", name = "AfgifteBestand")
    public JAXBElement<AfgifteBestandType> createAfgifteBestand(AfgifteBestandType value) {
        return new JAXBElement<AfgifteBestandType>(_AfgifteBestand_QNAME, AfgifteBestandType.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link AfgifteType }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://www.kadaster.nl/schemas/gds2/afgifte-bestandophalenresultaat/afgifte/v20130701", name = "Afgifte")
    public JAXBElement<AfgifteType> createAfgifte(AfgifteType value) {
        return new JAXBElement<AfgifteType>(_Afgifte_QNAME, AfgifteType.class, null, value);
    }

}

==> kadaster-gds2-2.0-sources.jar: nl/kadaster/schemas/gds2/afgifte_bestandophalenresultaat/afgifte/v20130701/ObjectFactory.java <==

package nl.kadaster.schemas.gds2.afgifte_bestandophalenresultaat.afgifte.v20130701;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlElementDecl;
import javax.xml.bind.annotation.XmlRegistry;
import javax.xml.namespace.QName;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the nl.kadaster.schemas.gds2.afgifte_bestandophalenresultaat.afgifte.v20130701 package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {

    private final static QName _Afgifte_QNAME = new QName("http://www.kadaster.nl/schemas/gds2/afgifte-bestandophalenresultaat/afgifte/v20130701", "Afgifte");
    private final static QName _AfgifteBestand_QNAME = new QName("http://www.kadaster.nl/schemas/gds2/afgifte-bestandophalenresultaat/afgifte/v20130701", "AfgifteBestand");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: nl.kadaster.schemas.gds2.afgifte_bestandophalenresultaat.afgifte.v20130701
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link AfgifteType }
     * 
     */
    public AfgifteType createAfgifteType() {
        return new AfgifteType();
    }

    /**
     * Create an instance of {@link AfgifteBestandType }
     * 
     */
    public AfgifteBestandType createAfgifteBestandType() {
        return new AfgifteBestandType();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link AfgifteType }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link AfgifteType }{@code >}
     */
    @XmlElementDecl(namespace = "http://www.kadaster.nl/schemas/gds2/afgifte-bestandophalenresultaat/afgifte/v20130701", name = "Afgifte")
    public JAXBElement<AfgifteType> createAfgifte(AfgifteType value) {
        return new JAXBElement<AfgifteType>(_Afgifte_QNAME, AfgifteType.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link AfgifteBestandType }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link AfgifteBestandType }{@code >}
     */
    @XmlElementDecl(namespace = "http://www.kadaster.nl/schemas/gds2/afgifte-bestandophalenresultaat/afgifte/v20130701", name = "AfgifteBestand")
    public JAXBElement<AfgifteBestandType> createAfgifteBestand(AfgifteBestandType value) {
        return new JAXBElement<AfgifteBestandType>(_AfgifteBestand_QNAME, AfgifteBestandType.class, null, value);
    }

}
